Index: src/compiler/simplified-lowering.h |
diff --git a/src/compiler/simplified-lowering.h b/src/compiler/simplified-lowering.h |
index c24408c7c2dfbe3d72c3ad3ebba0b83c7fddb25b..d71dcc23b7bbbe098246a442f83adb9c257a4f7f 100644 |
--- a/src/compiler/simplified-lowering.h |
+++ b/src/compiler/simplified-lowering.h |
@@ -31,9 +31,9 @@ class SimplifiedLowering final { |
void LowerAllNodes(); |
// TODO(turbofan): The output_type can be removed once the result of the |
// representation analysis is stored in the node bounds. |
- void DoLoadBuffer(Node* node, MachineType output_type, |
+ void DoLoadBuffer(Node* node, MachineRepresentation rep, |
RepresentationChanger* changer); |
void DoStoreBuffer(Node* node); |
void DoObjectIsNumber(Node* node); |
@@ -31,9 +31,9 @@ class SimplifiedLowering final { |
void LowerAllNodes(); |
- // TODO(turbofan): The output_type can be removed once the result of the |
+ // TODO(turbofan): The representation can be removed once the result of the |
// representation analysis is stored in the node bounds. |